--- mod_transform-0.6.0.orig/src/mod_transform.c        2004-10-18 18:01:50.000000000 +0200
+++ mod_transform-0.6.0/src/mod_transform.c     2010-01-19 00:05:40.000000000 +0100
@@ -23,6 +23,9 @@
 
 #include "mod_transform_private.h"
 
+#define XSLT_MAX_PARAMS      256
+
+
 static void transform_error_cb(void *ctx, const char *msg, ...)
 {
     va_list args;
@@ -61,6 +64,30 @@
     return NULL;
 }
 
+static void fill_params_array (request_rec * r,
+                               apr_pool_t * pool,
+                               apr_array_header_t * arr) {
+
+  /* NOTE: do we need CGI vars for something? */
+  ap_add_cgi_vars (r);
+  ap_add_common_vars (r);
+
+  int i;
+  const apr_table_t * tbl = r->subprocess_env;
+  const apr_array_header_t * tbl_arr = apr_table_elts (tbl);
+  const apr_table_entry_t * tbl_elts = (const apr_table_entry_t *) tbl_arr->elts;
+
+  for (i = 0; i < XSLT_MAX_PARAMS && i < tbl_arr->nelts; i++) {
+    *((const char **) apr_array_push (arr)) = apr_pstrdup (pool, tbl_elts [i].key);
+    *((const char **) apr_array_push (arr)) = apr_pstrdup (pool,
+        apr_psprintf (pool, "'%s'", tbl_elts [i].val));
+
+    //ap_log_rerror (APLOG_MARK, APLOG_WARNING, 0, r, "%s='%s'",
+    //               tbl_elts [i].key, tbl_elts [i].val);
+  }
+  *((const char **) apr_array_push (arr)) = NULL;
+}
+
 static apr_status_t transform_run(ap_filter_t * f, xmlDocPtr doc)
 {
     size_t length;
@@ -128,7 +155,11 @@
         return pass_failure(f, "XSLT: Loading of the XSLT File has failed", notes);
     }
 
-    result = xsltApplyStylesheet(transform, doc, 0);
+    apr_array_header_t * params;
+    params = apr_array_make (f->r->pool, 2*XSLT_MAX_PARAMS +1, sizeof (const char *));
+    fill_params_array (f->r, f->r->pool, params);
+
+    result = xsltApplyStylesheet (transform, doc, (const char **) params->elts);
     if (!result) {
         if (!stylesheet_is_cached) {
             xsltFreeStylesheet(transform);
